@@ -1,7 +1,7 @@
 use serde_derive::{Deserialize, Serialize};
 
-/// The chromosome information type
-#[derive(Debug, Clone, Deserialize, Serialize)]
+/// The information of a chromosome
+#[derive(Debug, Clone, Deserialize, Serialize, PartialEq, Eq)]
 pub struct Chrom {
     /// The human-readable name for this chromosome
     pub name: String,
